
/***********************************************************************************
  Filename: hello.c

  Description:  This example reads chip Id and IEEE address from CC2480.

  Press S1 to output chip Id and IEEE address on serial port.
  Configure the PC HyperTerminal for baudrate 9600 bps, 8 data bits
  no parity, and 1 stop bit.

***********************************************************************************/

/***********************************************************************************
* INCLUDES
*/
#include <hal_led.h>
#include <hal_board.h>
#include <hal_uart.h>
#include <hal_assert.h>
#include <util.h>

#include <cc2480.h>
#include <cc2480_rpc_spi.h>


/***********************************************************************************
* LOCAL VARIABLES
*/
static uint8 buf[8];

/***********************************************************************************
* LOCAL FUNCTIONS
*/

static void appPrintMenu(void);


/******************************************************************************
* @fn          appPrintMenu
*
* @brief       Prints menu on UART
*
* @param       none
*
* @return      none
*/
static void appPrintMenu(void)
{
    printStr("------------------------------\n");
    printStr("CC2480 Application Example\n");
    printStr("Hello\n");
    printStr("------------------------------\n\n");
}





/***********************************************************************************
* @fn          main
*
* @brief       This is the main entry of the "hello" application
*
* @param       none
*
* @return      none
*/
void main (void)
{
    uint8 chipId;
    uint8 status;
    uint32 ieeeLow, ieeeHigh;

    // Initalise board peripherals
    halBoardInit();


    // Indicate that device is powered
    halLedSet(1);

    // Initalise UART
    halUartInit(HAL_UART_BAUDRATE_9600, 0);

    // Print Logo
    appPrintMenu();


    // Puts MCU in endless loop
    while(TRUE) {

        // Wait for user to press S1
        while (!HAL_BUTTON_1_PUSHED());

        halMcuWaitMs(350);

        // Read Chip id and version
        chipId = cc2480GetChipId();

        // Output to serial port
        printKvpHex8bit("Product ID ", chipId);

        // Get IEEE address from CC2480 Device and store in MSP430 Internal RAM
        status = cc2480GetIEEEAddress(buf);

        // Status OK, output IEEE address low and high to serial port
        if (status == 0) {
            // No short address assigned
            printKvpHexIEEE("IEEE Address", buf);
		}
		printStr("\n");
    }
}


/***********************************************************************************
  Copyright 2008 Texas Instruments Incorporated. All rights reserved.

  IMPORTANT: Your use of this Software is limited to those specific rights
  granted under the terms of a software license agreement between the user
  who downloaded the software, his/her employer (which must be your employer)
  and Texas Instruments Incorporated (the "License").  You may not use this
  Software unless you agree to abide by the terms of the License. The License
  limits your use, and you acknowledge, that the Software may not be modified,
  copied or distributed unless embedded on a Texas Instruments microcontroller
  or used solely and exclusively in conjunction with a Texas Instruments radio
  frequency transceiver, which is integrated into your product.  Other than for
  the foregoing purpose, you may not use, reproduce, copy, prepare derivative
  works of, modify, distribute, perform, display or sell this Software and/or
  its documentation for any purpose.

  YOU FURTHER ACKNOWLEDGE AND AGREE THAT THE SOFTWARE AND DOCUMENTATION ARE
  PROVIDED AS IS WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED,
  INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF MERCHANTABILITY, TITLE,
  NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL
  TEXAS INSTRUMENTS OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER CONTRACT,
  NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR OTHER
  LEGAL EQUITABLE THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES
  INCLUDING BUT NOT LIMITED TO ANY INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE
  OR CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST DATA, COST OF PROCUREMENT
  OF SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY THIRD PARTIES
  (INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.

  Should you have any questions regarding your right to use this Software,
  contact Texas Instruments Incorporated at www.TI.com.
***********************************************************************************/
