
/***********************************************************************************
    Filename:     assy_ez430_rf2480.h

    Description:  Defines connections between the MSP430F2274 and the CC2480

    Copyright (c) 2006 by Texas Instruments, Inc.
    All Rights Reserved.  Permission to use, reproduce, copy, prepare
    derivative works, modify, distribute, perform, display or sell this
    software and/or its documentation for any purpose is prohibited
    without the express written consent of Texas Instruments, Inc.
***********************************************************************************/

#ifndef ASSY_EZ430_RF2480_H
#define ASSY_EZ430_RF2480_H

/***********************************************************************************
* INCLUDES
*/
#include <msp430x22x2.h>
#include <hal_msp430.h>
#include <hal_board.h>

/***********************************************************************************
* MACROS
*/

// MCU Pin Access
#ifndef MCU_PIN_DIR_OUT
#define MCU_PIN_DIR_OUT(port,bit)       st( P##port##DIR |= BV(bit); )
#endif
#ifndef MCU_PIN_DIR_IN
#define MCU_PIN_DIR_IN(port,bit)        st( P##port##DIR &= ~BV(bit); )
#endif

// MCU port control for SPI interface
#define ZACCEL_DISABLE_SPI_FUNC()       st( P3SEL &= ~(BV(1) | BV(2) | BV(3)); )
#define ZACCEL_ENABLE_SPI_FUNC()        st( P3SEL |= BV(1) | BV(2) | BV(3); )


// Outputs: Power and reset control
#define ZACCEL_RESET_SET()              MCU_IO_SET_LOW(HAL_BOARD_IO_ZACC_RST_PORT,HAL_BOARD_IO_ZACC_RST_PIN)
#define ZACCEL_RESET_CLR()              MCU_IO_SET_HIGH(HAL_BOARD_IO_ZACC_RST_PORT,HAL_BOARD_IO_ZACC_RST_PIN)
#define ZACCEL_RESET()                  st( \
                                        { volatile uint16 i; \
                                          ZACCEL_RESET_SET(); \
                                          while (--i) { asm("NOP"); }; \
                                          ZACCEL_RESET_CLR(); \
                                        } )

// Outputs: Configuration control
#define ZACCEL_CFG0_OPIN(v)             MCU_IO_SET(4,0,v)
#define ZACCEL_CFG1_OPIN(v)             MCU_IO_SET(4,1,v)


// Outputs: SPI interface
#define ZACCEL_CSN_EN()                 MCU_IO_SET_LOW(HAL_BOARD_IO_ZACC_SS_PORT,HAL_BOARD_IO_ZACC_SS_PIN)
#define ZACCEL_CSN_DIS()                MCU_IO_SET_HIGH(HAL_BOARD_IO_ZACC_SS_PORT,HAL_BOARD_IO_ZACC_SS_PIN)

// Z-Accel SPI macros
#define ZACCEL_MRDY_SET()               MCU_IO_SET_LOW(HAL_BOARD_IO_ZACC_MRDY_PORT, HAL_BOARD_IO_ZACC_MRDY_PIN)
#define ZACCEL_MRDY_CLR()               MCU_IO_SET_HIGH(HAL_BOARD_IO_ZACC_MRDY_PORT, HAL_BOARD_IO_ZACC_MRDY_PIN)

// Inputs: SPI interface
#define ZACCEL_SRDY_IN()                MCU_IO_GET(HAL_BOARD_IO_ZACC_SRDY_PORT,HAL_BOARD_IO_ZACC_SRDY_PIN)




// SPI register definitions
#define ZACCEL_SPI_TX_REG               (UCB0TXBUF)
#define ZACCEL_SPI_RX_REG               (UCB0RXBUF)
#define ZACCEL_SPI_RX_IS_READY()        (IFG2 & UCB0RXIFG)
#define ZACCEL_SPI_RX_NOT_READY()       (IFG2 &= ~UCB0RXIFG)

// SPI access macros
#define ZACCEL_SPI_BEGIN()               st( ZACCEL_MRDY_SET(); ZACCEL_CSN_EN();)
#define ZACCEL_SPI_TX(x)                 st( ZACCEL_SPI_RX_NOT_READY(); UCB0TXBUF = x; )

#define ZACCEL_SPI_RX()                  UCB0RXBUF
#define ZACCEL_SPI_WAIT_RXRDY()          st( while (!(ZACCEL_SPI_RX_IS_READY())); )
#define ZACCEL_SPI_END()                 st( ZACCEL_MRDY_CLR(); ZACCEL_CSN_DIS(); )

// RPC protocol on SREQ is to wait for slave to signal ready by setting its SRDY line to opposite.
#define ZACCEL_SRDY_SRSP()               (!(ZACCEL_SRDY_IN() == 0))

inline uint8 ZACCEL_SPI_TXRX(uint8 x) {
    ZACCEL_SPI_TX(x);
    ZACCEL_SPI_WAIT_RXRDY();
    return ZACCEL_SPI_RX();
}

/***********************************************************************************
* PUBLIC FUNCTIONS
*/
void halAssyInit(void);
void halAssyIoInit(void);

#endif
