/***********************************************************************************
  Filename:     hal_cc2480.h

  Description:  This file defines the interface to the CC2480 radio.

***********************************************************************************/
#ifndef HALCC2480_H
#define HALCC2480_H

/***********************************************************************************
* INCLUDES
*/
#include <hal_board.h>
#include "cc2480_rpc_spi.h"

/***********************************************************************************
* MACROS
*/
/* ------------------------------------------------------------------------------------------------
 *                                          Macros
 * ------------------------------------------------------------------------------------------------
 */

#define ZACCEL_NWK_CONN (                      \
  (cc2480NwkState == DEV_END_DEVICE_UNAUTH) || \
  (cc2480NwkState == DEV_END_DEVICE)        || \
  (cc2480NwkState == DEV_ROUTER)            || \
  (cc2480NwkState == DEV_ZB_COORD)             \
)

#define ZACCEL_NWK_RTR (                       \
  (cc2480NwkState == DEV_ROUTER)            || \
  (cc2480NwkState == DEV_ZB_COORD)             \
)

#define ZACCEL_NWK_COOR  (cc2480NwkState == DEV_ZB_COORD)



/***********************************************************************************
* GLOBAL FUNCTIONS
*/
uint16 cc2480SoftReset(void);
uint16 cc2480HardReset(void);
uint8  cc2480GetChipId(void);
uint8  cc2480GetIEEEAddress(uint8* buffer);
uint8  cc2480Write(uint8* data, uint8 length);
uint8  cc2480Read(uint8* data, uint8 length);

/* ------------------------------------------------------------------------------------------------
 *                                          Typedefs
 * ------------------------------------------------------------------------------------------------
 */

typedef enum
{
  DEV_HOLD,               // Initialized - not started automatically
  DEV_INIT,               // Initialized - not connected to anything
  DEV_NWK_DISC,           // Discovering PAN's to join
  DEV_NWK_JOINING,        // Joining a PAN
  DEV_NWK_REJOIN,         // ReJoining a PAN, only for end devices
  DEV_END_DEVICE_UNAUTH,  // Joined but not yet authenticated by trust center
  DEV_END_DEVICE,         // Started as device after authentication
  DEV_ROUTER,             // Device joined, authenticated and is a router
  DEV_COORD_STARTING,     // Started as Zigbee Coordinator
  DEV_ZB_COORD,           // Started as Zigbee Coordinator
  DEV_NWK_ORPHAN          // Device has lost information about its parent..
} cc2480DevStates_t;

#endif

/***********************************************************************************
* GLOBAL VARIABLES
*/
extern cc2480DevStates_t cc2480NwkState;
extern uint16 cc2480NwkAddr;

extern uint16 cc2480EvtFlags;
extern uint16 cc2480IndFlags;

extern uint16 cc2480DataCmd, cc2480DataSrc, cc2480DataLen;
extern uint8 cc2480DataBuf[RPC_MAX_BUF];


/***********************************************************************************
  Copyright 2007 Texas Instruments Incorporated. All rights reserved.

  IMPORTANT: Your use of this Software is limited to those specific rights
  granted under the terms of a software license agreement between the user
  who downloaded the software, his/her employer (which must be your employer)
  and Texas Instruments Incorporated (the "License").  You may not use this
  Software unless you agree to abide by the terms of the License. The License
  limits your use, and you acknowledge, that the Software may not be modified,
  copied or distributed unless embedded on a Texas Instruments microcontroller
  or used solely and exclusively in conjunction with a Texas Instruments radio
  frequency transceiver, which is integrated into your product.  Other than for
  the foregoing purpose, you may not use, reproduce, copy, prepare derivative
  works of, modify, distribute, perform, display or sell this Software and/or
  its documentation for any purpose.

  YOU FURTHER ACKNOWLEDGE AND AGREE THAT THE SOFTWARE AND DOCUMENTATION ARE
  PROVIDED AS IS WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED,
  INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF MERCHANTABILITY, TITLE,
  NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL
  TEXAS INSTRUMENTS OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER CONTRACT,
  NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR OTHER
  LEGAL EQUITABLE THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES
  INCLUDING BUT NOT LIMITED TO ANY INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE
  OR CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST DATA, COST OF PROCUREMENT
  OF SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY THIRD PARTIES
  (INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.

  Should you have any questions regarding your right to use this Software,
  contact Texas Instruments Incorporated at www.TI.com.
***********************************************************************************/
