/***********************************************************************************
    Filename:     rpc_spi_cc2480.h

	Description:  RPC SPI common header file.

************************************************************************************/

#ifndef RPC_SPI_CC2480_H
#define RPC_SPI_CC2480_H

#ifdef __cplusplus
extern "C" {
#endif

/***********************************************************************************
* INCLUDES
*/
#include "hal_defs.h"
#include "hal_types.h"


/***********************************************************************************
* CONSTANTS
*/
#define RPC_SUCCESS                        0x00
#define RPC_POS_LEN                        0
#define RPC_POS_CMD0                       1
#define RPC_POS_CMD1                       2
#define RPC_POS_PARAM                      3

#define RPC_MAX_BUF                        256
#define RPC_CMD_POLL                       0x00
#define RPC_CMD_SREQ                       0x20
#define RPC_CMD_AREQ                       0x40

#define RPC_CMD_SRSP                       0x61
#define RPC_CMD_RES4                       0x80
#define RPC_CMD_RES5                       0xA0
#define RPC_CMD_RES6                       0xC0
#define RPC_CMD_RES7                       0xE0

#define RPC_CMDSUBSYS_SYS                  0x01
#define RPC_CMDSUBSYS_AF                   0x04
#define RPC_CMDSUBSYS_ZDO                  0x05
#define RPC_CMDSUBSYS_SAPI                 0x06

#define CMDID_SYS_RESET_REQ                0x00
#define CMDID_SYS_VERSION                  0x02
#define CMDID_ZB_GET_DEVICE_INFO           0x06
#define CMDID_ZB_PERMIT_JOINING_REQ        0x08
#define CMDID_SYS_OSAL_NV_WRITE            0x09
#define CMDID_SYS_RESET_IND                0x80
#define CMDID_ZB_APP_REGISTER_REQ          0x0A
#define CMDID_ZB_SYS_RESET                 0x09

#define CMD_SYS_RESET_IND_AREQ             0x4180
#define CMD_SYS_VERSION_SRSP               0x6102

/***************************************************************************************************
 * SAPI COMMANDS IDENTIFIERS
 ***************************************************************************************************/
#define CMDID_SAPI_BIND_DEVICE_REQ         0x01
#define CMDID_SAPI_ALLOW_BIND_REQ          0x02
#define CMDID_SAPI_SEND_DATA_REQ           0x03
#define CMDID_SAPI_READ_CFG_REQ            0x04
#define CMDID_SAPI_WRITE_CFG_REQ           0x05
#define CMDID_SAPI_GET_DEV_INFO_REQ        0x06
#define CMDID_SAPI_FIND_DEV_REQ            0x07
#define CMDID_SAPI_PMT_JOIN_REQ            0x08
#define CMDID_SAPI_APP_REGISTER_REQ        0x0a

#define ZSUCCESS                           0x00
#define ZFAILURE                           0x01
#define ZINVALIDPARAM                      0x02

#define Z_EXTADDR_LEN                      8
#define INVALID_NODE_ADDR                  0xFFFE

#define AF_FRAGMENTED                      0x01
#define AF_ACK_REQUEST                     0x10
#define AF_DISCV_ROUTE                     0x20
#define AF_EN_SECURITY                     0x40
#define AF_SKIP_ROUTING                    0x80

#define NWK_BROADCAST_SHORTADDR_DEVALL     0xFFFF
#define NWK_BROADCAST_SHORTADDR            NWK_BROADCAST_SHORTADDR_DEVALL
// The default network radius set twice the value of <nwkMaxDepth>.
#define DEF_NWK_RADIUS                     10
#define AF_DEFAULT_RADIUS                  DEF_NWK_RADIUS

// OSAL NV item IDs
#define ZCD_NV_EXTADDR                     0x0001
#define ZCD_NV_BOOTCOUNTER                 0x0002
#define ZCD_NV_STARTUP_OPTION              0x0003
#define ZCD_NV_START_DELAY                 0x0004

// ZDO NV Item IDs
#define ZCD_NV_USERDESC                    0x0081
#define ZCD_NV_NWKKEY                      0x0082
#define ZCD_NV_PANID                       0x0083
#define ZCD_NV_CHANLIST                    0x0084
#define ZCD_NV_LEAVE_CTRL                  0x0085
#define ZCD_NV_SCAN_DURATION               0x0086
#define ZCD_NV_LOGICAL_TYPE                0x0087

// NWK Layer NV item IDs
#define ZCD_NV_POLL_RATE                   0x0024
#define ZCD_NV_QUEUED_POLL_RATE            0x0025
#define ZCD_NV_RESPONSE_POLL_RATE          0x0026


// ZCD_NV_STARTUP_OPTION values
//   These are bit weighted - you can OR these together.
//   Setting one of these bits will set their associated NV items
//   to code initialized values.
#define ZCD_STARTOPT_DEFAULT_CONFIG_STATE  0x01
#define ZCD_STARTOPT_DEFAULT_NETWORK_STATE 0x02
#define ZCD_STARTOPT_AUTO_START            0x04
#define ZCD_STARTOPT_CLEAR_CONFIG          ZCD_STARTOPT_DEFAULT_CONFIG_STATE
#define ZCD_STARTOPT_RESTORE_STATE         ZCD_STARTOPT_DEFAULT_NETWORK_STATE


/***********************************************************************************
* GLOBAL VARIABLES
*/
extern uint8 hostMsgBuf[];


/***********************************************************************************
* PUBLIC FUNCTIONS
*/
uint8 cc2480Rpc(uint8 *pBuf);
uint8 cc2480RpcPoll(uint8 *pBuf);


#ifdef __cplusplus
}
#endif

#endif


/***********************************************************************************
  Copyright 2007 Texas Instruments Incorporated. All rights reserved.

  IMPORTANT: Your use of this Software is limited to those specific rights
  granted under the terms of a software license agreement between the user
  who downloaded the software, his/her employer (which must be your employer)
  and Texas Instruments Incorporated (the "License").  You may not use this
  Software unless you agree to abide by the terms of the License. The License
  limits your use, and you acknowledge, that the Software may not be modified,
  copied or distributed unless embedded on a Texas Instruments microcontroller
  or used solely and exclusively in conjunction with a Texas Instruments radio
  frequency transceiver, which is integrated into your product.  Other than for
  the foregoing purpose, you may not use, reproduce, copy, prepare derivative
  works of, modify, distribute, perform, display or sell this Software and/or
  its documentation for any purpose.

  YOU FURTHER ACKNOWLEDGE AND AGREE THAT THE SOFTWARE AND DOCUMENTATION ARE
  PROVIDED AS IS WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED,
  INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF MERCHANTABILITY, TITLE,
  NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL
  TEXAS INSTRUMENTS OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER CONTRACT,
  NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR OTHER
  LEGAL EQUITABLE THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES
  INCLUDING BUT NOT LIMITED TO ANY INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE
  OR CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST DATA, COST OF PROCUREMENT
  OF SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY THIRD PARTIES
  (INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.

  Should you have any questions regarding your right to use this Software,
  contact Texas Instruments Incorporated at www.TI.com.
***********************************************************************************/
