/******************************************************************************
    Filename:     hal_board.h

    Description:  HAL board peripherals header file for the
                  SmartRF05EB + CCMSP-EM430FG2618 platform

    Copyright 2007 Texas Instruments, Inc.

******************************************************************************/
#ifndef HAL_BOARD_H
#define HAL_BOARD_H

#ifdef __cplusplus
extern "C" {
#endif

/******************************************************************************
 * INCLUDES
 */
#include "hal_types.h"
#include "hal_defs.h"
#include "hal_mcu.h"

#if defined ASSY_EZ430_RF2480
#include "assy_ez430_rf2480.h"
#else
#error "No assembly chosen"
#endif

/******************************************************************************
 * CONSTANTS
 */

#define HAL_BOARD_IO_LED_1_PORT         1
#define HAL_BOARD_IO_LED_1_PIN          0

#define HAL_BOARD_IO_LED_2_PORT         1
#define HAL_BOARD_IO_LED_2_PIN          1

#define HAL_BOARD_IO_BTN_1_PORT         1
#define HAL_BOARD_IO_BTN_1_PIN          2

#define HAL_BOARD_IO_LS_SEL_PORT        2
#define HAL_BOARD_IO_LS_SEL_PIN         1

#define HAL_BOARD_IO_UART_RTS_PORT      3
#define HAL_BOARD_IO_UART_RTS_PIN       3

#define HAL_BOARD_IO_LS_LEVEL_PORT      2
#define HAL_BOARD_IO_LS_LEVEL_PIN       0

#define HAL_BOARD_IO_ZACC_SRDY_PORT     2
#define HAL_BOARD_IO_ZACC_SRDY_PIN      6

#define HAL_BOARD_IO_ZACC_SS_PORT       3
#define HAL_BOARD_IO_ZACC_SS_PIN        0

#define HAL_BOARD_UART_TX_PORT          3
#define HAL_BOARD_UART_TX_PIN           4

#define HAL_BOARD_UART_RX_PORT          3
#define HAL_BOARD_UART_RX_PIN           5

#define HAL_BOARD_IO_ZACC_MRDY_PORT     3
#define HAL_BOARD_IO_ZACC_MRDY_PIN      6

#define HAL_BOARD_IO_ZACC_RST_PORT      3
#define HAL_BOARD_IO_ZACC_RST_PIN       7

#define HAL_BOARD_IO_ZACC_CFG0_PORT     4
#define HAL_BOARD_IO_ZACC_CFG0_PIN      0

#define HAL_BOARD_IO_ZACC_CFG1_PORT     4
#define HAL_BOARD_IO_ZACC_CFG1_PIN      1

#define HAL_BOARD_IO_ZACC_DBGDC_PORT    4
#define HAL_BOARD_IO_ZACC_DBGDC_PIN     2

#define HAL_BOARD_IO_ZACC_DBGDD_PORT    4
#define HAL_BOARD_IO_ZACC_DBGDD_PIN     3

/******************************************************************************
 * MACROS
 */

// LED
#define HAL_LED_SET_1()                 MCU_IO_SET_HIGH(HAL_BOARD_IO_LED_1_PORT, HAL_BOARD_IO_LED_1_PIN)
#define HAL_LED_SET_2()                 MCU_IO_SET_HIGH(HAL_BOARD_IO_LED_2_PORT, HAL_BOARD_IO_LED_2_PIN)
#define HAL_LED_DIR_OUT_1()             MCU_IO_OUTPUT(HAL_BOARD_IO_LED_1_PORT, HAL_BOARD_IO_LED_1_PIN, 0);
#define HAL_LED_DIR_OUT_2()             MCU_IO_OUTPUT(HAL_BOARD_IO_LED_2_PORT, HAL_BOARD_IO_LED_2_PIN, 0);

#define HAL_LED_CLR_1()                 MCU_IO_SET_LOW(HAL_BOARD_IO_LED_1_PORT, HAL_BOARD_IO_LED_1_PIN)
#define HAL_LED_CLR_2()                 MCU_IO_SET_LOW(HAL_BOARD_IO_LED_2_PORT, HAL_BOARD_IO_LED_2_PIN)

#define HAL_LED_TGL_1()                 MCU_IO_TGL(HAL_BOARD_IO_LED_1_PORT, HAL_BOARD_IO_LED_1_PIN)
#define HAL_LED_TGL_2()                 MCU_IO_TGL(HAL_BOARD_IO_LED_2_PORT, HAL_BOARD_IO_LED_2_PIN)

// UART RTS
#define HAL_RTS_SET()                   MCU_IO_SET_HIGH(HAL_BOARD_IO_UART_RTS_PORT, HAL_BOARD_IO_UART_RTS_PIN)
#define HAL_RTS_CLR()                   MCU_IO_SET_LOW(HAL_BOARD_IO_UART_RTS_PORT, HAL_BOARD_IO_UART_RTS_PIN)
#define HAL_RTS_DIR_OUT()               MCU_IO_OUTPUT(HAL_BOARD_IO_UART_RTS_PORT, HAL_BOARD_IO_UART_RTS_PIN, 0)

// Buttons
#define HAL_BUTTON_1_PUSHED()           (!MCU_IO_GET(HAL_BOARD_IO_BTN_1_PORT, HAL_BOARD_IO_BTN_1_PIN))

// Light Sensor
#define HAL_LS_DIR_OUT()                MCU_IO_OUTPUT(HAL_BOARD_IO_LS_SEL_PORT, HAL_BOARD_IO_LS_SEL_PIN,0)
#define HAL_LS_EN()                     MCU_IO_OUTPUT(HAL_BOARD_IO_LS_SEL_PORT, HAL_BOARD_IO_LS_SEL_PIN,1)
#define HAL_LS_DIS()                    MCU_IO_OUTPUT(HAL_BOARD_IO_LS_SEL_PORT, HAL_BOARD_IO_LS_SEL_PIN,0)



/******************************************************************************
 * GLOBAL VARIABLES
 */

/******************************************************************************
 * GLOBAL FUNCTIONS
 */

void halBoardInit(void);


#ifdef __cplusplus
}
#endif

/*****************************************************************************/
#endif
