
/***********************************************************************************
    Filename:     hal_potmeter.c

    Description:  Functions for reading the value from the potmeter

    Copyright 2007 Texas Instruments, Inc.
***********************************************************************************/

/***********************************************************************************
* INCLUDES
*/
#include "hal_types.h"
#include "hal_defs.h"
#include "hal_board.h"
#include "hal_lightsensor.h"

/***********************************************************************************
 * @fn          halLightSensorRead
 *
 * @brief       Reads the value from the light sensor on ZAccel DB. Returns an 8 bit
 *              value ranging from 0x00 to 0xff
 *
 * @param       none
 *
 * @return      8 bit value from potmeter
 */
uint8 halLightSensorRead(void)
{
    // Read the analog value on A0 to get the potmeter level
    uint16 value;

    HAL_LS_EN();                       // Enable Light Sensor

    ADC10CTL0 = ADC10SHT_2 + ADC10ON ; // Sampling time, ADC10 on
    ADC10AE0 |= 0x01;                   // Sample channel A0
    ADC10CTL0 |= ENC + ADC10SC;          // Enable and Start conversions
    while (!(ADC10IFG & 0x0004));       // Conversion done?
    value      = ADC10MEM;              // Access result
    ADC10CTL0  = 0;                     // Turn ADC off

    HAL_LS_DIS();                      // Disable Light Sensor;
    return ((uint8)(value >> 6));

}




