/*********************************************************************
    
    Filename:       util_console.h

    Description:    Various console functions.

    Notes:

*********************************************************************/

#ifndef TE_DEMO_CONSOLE_H
#define TE_DEMO_CONSOLE_H

#ifdef WIN32

#ifdef __cplusplus
extern "C"
{
#endif

/*********************************************************************
 * INCLUDES
 */
#include "hal_types.h"

/*********************************************************************
 * COMPILER switches
 */

// For use with AVR (RAM shortage)
#if defined (CC2420DB)
#define CONSOLE_REDUCED_OUTPUT
#endif

// For use with CC2430, non-banked mode (flash shortage)
#ifdef __ICC8051__
#if __CODE_MODEL__==2
#define CONSOLE_REDUCED_OUTPUT
#endif
#endif

/*********************************************************************
 * CONSTANTS
 */

#define NO_HEX_INDICATION   0x80    // display hex numbers without trailing 'h'
#define KVP_ALIGN           24      // Default padding for printKvpInt/hex


// File descriptor for the operator console
#define FD_UART             0
#define FD_REMOTE           1

/*********************************************************************
 * MACROS
 */

// Print the name and value of a structure member reference (HEX)
#define printKvpHexM(p,m)   printKvpHex(#m##, p->m)

// Print the name and value of a structure member reference (INT)
#define printKvpIntM(p,m)   printKvpInt(#m##, p->m)

// Print the name and value of a variable (INT)
#define printKvpIntV(v)     printKvpInt(#v##, v)

// Print the name and value of a variable (HEX)
#define printKvpHexV(v)     printKvpHex(#v##, v)

/*********************************************************************
 * TYPEDEFS
 */

/*********************************************************************
 * PUBLIC FUNCTIONS
 */

void    printChar(char c);
void    printStr(char FAR *sz);
void    printInt(uint32 i);
void    printHex(uint32 qw, uint8 iRadix);
void    printKvpInt(char FAR *szKey, uint32 v);
void    printKvpHex(char FAR *szKey, uint16 v);

void    setStdout(uint8 fd);
void    printTime(uint32 nMsec);
void    printStrW(char FAR *sz, uint8 len);
void    printMenu(void);
void    printLine(uint8 c, uint8 n);
void    printStrCode(const char CODE *p);


#ifdef __cplusplus
}
#endif

#endif
#endif