/******************************************************************************
  Copyright 2007 Texas Instruments Incorporated. All rights reserved.

  IMPORTANT: Your use of this Software is limited to those specific rights
  granted under the terms of a software license agreement between the user
  who downloaded the software, his/her employer (which must be your employer)
  and Texas Instruments Incorporated (the "License").  You may not use this
  Software unless you agree to abide by the terms of the License. The License
  limits your use, and you acknowledge, that the Software may not be modified,
  copied or distributed unless embedded on a Texas Instruments microcontroller
  or used solely and exclusively in conjunction with a Texas Instruments radio
  frequency transceiver, which is integrated into your product.  Other than for
  the foregoing purpose, you may not use, reproduce, copy, prepare derivative
  works of, modify, distribute, perform, display or sell this Software and/or
  its documentation for any purpose.

  YOU FURTHER ACKNOWLEDGE AND AGREE THAT THE SOFTWARE AND DOCUMENTATION ARE
  PROVIDED AS IS WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED,
  INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF MERCHANTABILITY, TITLE,
  NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL
  TEXAS INSTRUMENTS OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER CONTRACT,
  NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR OTHER
  LEGAL EQUITABLE THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES
  INCLUDING BUT NOT LIMITED TO ANY INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE
  OR CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST DATA, COST OF PROCUREMENT
  OF SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY THIRD PARTIES
  (INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.

  Should you have any questions regarding your right to use this Software,
  contact Texas Instruments Incorporated at www.TI.com.
******************************************************************************/

/******************************************************************************
  Filename:     util_mem.c

  Description:  Memory related utility functions

******************************************************************************/

/******************************************************************************
* INCLUDES
*/

#include "util_mem.h"
#include "hal_types.h"


/******************************************************************************
* LOCAL VARIABLES
*/


/******************************************************************************
* GLOBAL FUNCTIONS
*/


/******************************************************************************
* @fn       utilMemcpy
*
* @brief    Copy num bytes from pDest to pSrc
*
* @param    pDest - pointer to destination memory area
*           pSrc - pointer to source memory area
*           num - number of characters/bytes to copy
*
* @return   void
*/
void utilMemcpy(void __generic *pDest, const void __generic *pSrc, uint16 num)
{
    uint8 __generic *pD = (uint8 __generic *) pDest;
    uint8 __generic *pS = (uint8 __generic *) pSrc;

    while (num--) {
        *(pD++) = *(pS++);
    }
}


/******************************************************************************
* @fn       utilMemcmp
*
* @brief    Compares the first num bytes of two sequences s1 and s2.
*
* @param    pA  - pointer to memory area A
*           pB  - pointer to memory area B
*           num - number of characters/bytes to compare
*
* @return   0     - equal, pA == pB
*           other - not equal, pA != pB
*/
uint8 utilMemcmp(const void __generic *s1, const void __generic *s2, uint16 num)
{
    uint8 __generic *a = (uint8 __generic *) s1;
    uint8 __generic *b = (uint8 __generic *) s2;

    for ( ; num--; a++, b++) {
        if (*a != *b) {
            return (*a - *b);
        }
    }

    return 0;
}
